# PulpcoreClient::ExportersCoreExportsApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ExportersCoreExportsApi.md#create) | **POST** {pulp_exporter_href}exports/ | Create a pulp export
[**delete**](ExportersCoreExportsApi.md#delete) | **DELETE** {pulp_export_href} | Delete a pulp export
[**list**](ExportersCoreExportsApi.md#list) | **GET** {pulp_exporter_href}exports/ | List pulp exports
[**read**](ExportersCoreExportsApi.md#read) | **GET** {pulp_export_href} | Inspect a pulp export



## create

> AsyncOperationResponse create(pulp_exporter_href, data)

Create a pulp export

Trigger an asynchronous task to export a set of repositories

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: Basic
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersCoreExportsApi.new
pulp_exporter_href = 'pulp_exporter_href_example' # String | URI of Pulp Exporter. e.g.: /pulp/api/v3/exporters/core/pulp/1/
data = PulpcoreClient::PulpExport.new # PulpExport | 

begin
  #Create a pulp export
  result = api_instance.create(pulp_exporter_href, data)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersCoreExportsApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pulp_exporter_href** | **String**| URI of Pulp Exporter. e.g.: /pulp/api/v3/exporters/core/pulp/1/ | 
 **data** | [**PulpExport**](PulpExport.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[Basic](../README.md#Basic)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## delete

> delete(pulp_export_href)

Delete a pulp export

ViewSet for viewing exports from a PulpExporter.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: Basic
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersCoreExportsApi.new
pulp_export_href = 'pulp_export_href_example' # String | URI of Pulp Export. e.g.: /pulp/api/v3/exporters/core/pulp/1/exports/1/

begin
  #Delete a pulp export
  api_instance.delete(pulp_export_href)
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersCoreExportsApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pulp_export_href** | **String**| URI of Pulp Export. e.g.: /pulp/api/v3/exporters/core/pulp/1/exports/1/ | 

### Return type

nil (empty response body)

### Authorization

[Basic](../README.md#Basic)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## list

> InlineResponse2002 list(pulp_exporter_href, opts)

List pulp exports

ViewSet for viewing exports from a PulpExporter.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: Basic
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersCoreExportsApi.new
pulp_exporter_href = 'pulp_exporter_href_example' # String | URI of Pulp Exporter. e.g.: /pulp/api/v3/exporters/core/pulp/1/
opts = {
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List pulp exports
  result = api_instance.list(pulp_exporter_href, opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersCoreExportsApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pulp_exporter_href** | **String**| URI of Pulp Exporter. e.g.: /pulp/api/v3/exporters/core/pulp/1/ | 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**InlineResponse2002**](InlineResponse2002.md)

### Authorization

[Basic](../README.md#Basic)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> PulpExportRead read(pulp_export_href, opts)

Inspect a pulp export

ViewSet for viewing exports from a PulpExporter.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: Basic
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersCoreExportsApi.new
pulp_export_href = 'pulp_export_href_example' # String | URI of Pulp Export. e.g.: /pulp/api/v3/exporters/core/pulp/1/exports/1/
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a pulp export
  result = api_instance.read(pulp_export_href, opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersCoreExportsApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pulp_export_href** | **String**| URI of Pulp Export. e.g.: /pulp/api/v3/exporters/core/pulp/1/exports/1/ | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PulpExportRead**](PulpExportRead.md)

### Authorization

[Basic](../README.md#Basic)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

