# PulpcoreClient::ImportersCoreImportsApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ImportersCoreImportsApi.md#create) | **POST** {pulp_importer_href}imports/ | Create a pulp import
[**delete**](ImportersCoreImportsApi.md#delete) | **DELETE** {pulp_import_href} | Delete a pulp import
[**list**](ImportersCoreImportsApi.md#list) | **GET** {pulp_importer_href}imports/ | List pulp imports
[**read**](ImportersCoreImportsApi.md#read) | **GET** {pulp_import_href} | Inspect a pulp import



## create

> AsyncOperationResponse create(pulp_importer_href, data)

Create a pulp import

Trigger an asynchronous task to import a Pulp export.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: Basic
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ImportersCoreImportsApi.new
pulp_importer_href = 'pulp_importer_href_example' # String | URI of Pulp Importer. e.g.: /pulp/api/v3/importers/core/pulp/1/
data = PulpcoreClient::PulpImport.new # PulpImport | 

begin
  #Create a pulp import
  result = api_instance.create(pulp_importer_href, data)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ImportersCoreImportsApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pulp_importer_href** | **String**| URI of Pulp Importer. e.g.: /pulp/api/v3/importers/core/pulp/1/ | 
 **data** | [**PulpImport**](PulpImport.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[Basic](../README.md#Basic)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## delete

> delete(pulp_import_href)

Delete a pulp import

ViewSet for PulpImports.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: Basic
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ImportersCoreImportsApi.new
pulp_import_href = 'pulp_import_href_example' # String | URI of Pulp Import. e.g.: /pulp/api/v3/importers/core/pulp/1/imports/1/

begin
  #Delete a pulp import
  api_instance.delete(pulp_import_href)
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ImportersCoreImportsApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pulp_import_href** | **String**| URI of Pulp Import. e.g.: /pulp/api/v3/importers/core/pulp/1/imports/1/ | 

### Return type

nil (empty response body)

### Authorization

[Basic](../README.md#Basic)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## list

> InlineResponse2004 list(pulp_importer_href, opts)

List pulp imports

ViewSet for PulpImports.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: Basic
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ImportersCoreImportsApi.new
pulp_importer_href = 'pulp_importer_href_example' # String | URI of Pulp Importer. e.g.: /pulp/api/v3/importers/core/pulp/1/
opts = {
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List pulp imports
  result = api_instance.list(pulp_importer_href, opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ImportersCoreImportsApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pulp_importer_href** | **String**| URI of Pulp Importer. e.g.: /pulp/api/v3/importers/core/pulp/1/ | 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**InlineResponse2004**](InlineResponse2004.md)

### Authorization

[Basic](../README.md#Basic)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> ImportRead read(pulp_import_href, opts)

Inspect a pulp import

ViewSet for PulpImports.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: Basic
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ImportersCoreImportsApi.new
pulp_import_href = 'pulp_import_href_example' # String | URI of Pulp Import. e.g.: /pulp/api/v3/importers/core/pulp/1/imports/1/
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a pulp import
  result = api_instance.read(pulp_import_href, opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ImportersCoreImportsApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pulp_import_href** | **String**| URI of Pulp Import. e.g.: /pulp/api/v3/importers/core/pulp/1/imports/1/ | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**ImportRead**](ImportRead.md)

### Authorization

[Basic](../README.md#Basic)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

